Parse pyproject.toml (parser) — pyproject2conda v0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# Parse pyproject.toml (parser)

# Parse pyproject.toml (`parser`)

Main parser to turn pyproject.toml to other formats.

Functions:

`value_comment_pairs_to_conda`(value_comment_list) | Convert raw value/comment pairs to install lines

Classes:

`PyProject2Conda`(data[, name, channels, ...]) | Wrapper class to transform pyproject.toml -> environment.yaml

pyproject2conda.parser.value_comment_pairs_to_conda(value_comment_list, sort=True, deps=None, reqs=None)

  Convert raw value/comment pairs to install lines

class pyproject2conda.parser.PyProject2Conda(data, name=None, channels=None, python_include=None)

  Bases: `object`

  Wrapper class to transform pyproject.toml -> environment.yaml

  Methods:

  `to_requirements`([extras, ...]) | Create requirements.txt like file with pip dependencies.

  to_requirements(extras=None, include_base_dependencies=True, header_cmd=None, stream=None, sort=True, reqs=None, allow_empty=False)

    Create requirements.txt like file with pip dependencies.